#!/usr/bin/Rscript

library(tidyverse)
library(optparse)

# get arguments from command line
options = list(
	make_option(c("-i", "--input"), type = "character", default=NULL, help="Path to CSV file of nucleotide composition (output from seqtk comp)", metavar="character"),
	make_option(c("-o", "--output_png"), type="character", default="gene_length_distribution.png", help="output PNG image", metavar="character")
	);
option_parser = OptionParser(option_list=options);
opt = parse_args(option_parser);


# import sequence length files
df=read.table(opt$input,header=F)

# add category column
df$category <-rep("all_v1.1",nrow(df))

# generate violin plot to check if the distributions are similar between the full gene set and my sample gene set (20% random selection with seqtk)
png(opt$output_png)
ggplot(df, aes(x=df$category, y=log10(df$V2), fill=df$category)) + geom_violin() + theme(legend.position="none") + labs(title="length distribution of gene features", x="category", y="gene length (log10)")
dev.off()

